<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
-->

[![](https://img.shields.io/badge/OS-macOS-blue.svg?longCache=True)]()

#### Installation
```bash
$ [sudo] pip install mac-app-frontmost
```

#### Scripts usage
```bash
usage: app-frontmost --bundleid|--name|--path|--pid
```

#### Examples
```bash
$ app-frontmost --bundleid
com.apple.Terminal

$ app-frontmost --name
Terminal

$ app-frontmost --path
/Applications/Utilities/Terminal.app

$ app-frontmost --pid
304
```

<p align="center">
    <a href="https://pypi.org/project/python-readme-generator/">python-readme-generator</a>
</p>